![Community project](https://raw.githubusercontent.com/softbutterfly/wagtail-sb-socialnetworks/master/resources/softbutterfly-open-source-community-project.png)

![PyPI - Supported versions](https://img.shields.io/pypi/pyversions/wagtail-sb-socialnetworks)
![PyPI - Package version](https://img.shields.io/pypi/v/wagtail-sb-socialnetworks)
![PyPI - Downloads](https://img.shields.io/pypi/dm/wagtail-sb-socialnetworks)
![PyPI - MIT License](https://img.shields.io/pypi/l/wagtail-sb-socialnetworks)

[![Build Status](https://www.travis-ci.org/softbutterfly/wagtail-sb-socialnetworks.svg?branch=develop)](https://www.travis-ci.org/softbutterfly/wagtail-sb-socialnetworks)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/3d703e48c1e44e9b830da5026f07c52d)](https://www.codacy.com/gh/softbutterfly/wagtail-sb-socialnetworks/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=softbutterfly/wagtail-sb-socialnetworks&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/3d703e48c1e44e9b830da5026f07c52d)](https://www.codacy.com/gh/softbutterfly/wagtail-sb-socialnetworks/dashboard?utm_source=github.com&utm_medium=referral&utm_content=softbutterfly/wagtail-sb-socialnetworks&utm_campaign=Badge_Coverage)
[![codecov](https://codecov.io/gh/softbutterfly/wagtail-sb-socialnetworks/branch/master/graph/badge.svg?token=pbqXUUOu1F)](https://codecov.io/gh/softbutterfly/wagtail-sb-socialnetworks)
[![Requirements Status](https://requires.io/github/softbutterfly/wagtail-sb-socialnetworks/requirements.svg?branch=master)](https://requires.io/github/softbutterfly/wagtail-sb-socialnetworks/requirements/?branch=master)

# Wagtail Social Networks

Wagtail package to manage sites social network profiles.

## Requirements

- Python 3.6, 3.7, 3.8, 3.9

## Install

```bash
pip install wagtail-sb-socialnetworks
```

## Usage

Add `wagtail.contrib.settings` and `wagtail_sb_socialnetworks` to your `INSTALLED_APPS` settings

```
INSTALLED_APPS = [
  # ...
  "wagtail.contrib.settings",
  "wagtail_sb_socialnetworks",
  # ...
]
```

## Docs

- [Ejemplos](https://github.com/softbutterfly/wagtail-sb-socialnetworks/wiki)
- [Wiki](https://github.com/softbutterfly/wagtail-sb-socialnetworks/wiki)

## Changelog

All changes to versions of this library are listed in the [change history](CHANGELOG.md).

## Development

Check out our [contribution guide](CONTRIBUTING.md).

## Contributors

See the list of contributors [here](https://github.com/softbutterfly/wagtail-sb-socialnetworks/graphs/contributors).
